Re: [AD] Compilation problem on Darwin

[ Thread Index | Date Index | More lists.liballeg.org/allegro-developers Archives ]


On Mon, Sep 23, 2002 at 09:52:05AM +0200, Eric Botcazou wrote:
> It seems that gcc chockes on the '"' construct (which also confuses a
> lot my editor btw).

Would this fix the problem?
Index: docs/src/makedoc/maketexi.c
===================================================================
RCS file: /cvsroot/alleg/allegro/docs/src/makedoc/maketexi.c,v
retrieving revision 1.5
diff -u -r1.5 maketexi.c
--- docs/src/makedoc/maketexi.c	17 Sep 2002 21:31:57 -0000	1.5
+++ docs/src/makedoc/maketexi.c	25 Sep 2002 17:39:41 -0000
@@ -31,6 +31,7 @@
 #include "makedoc.h"
 #include "makemisc.h"
 
+#define DOUBLE_QUOTES           34
 
 int multiwordheaders = 0;
 
@@ -115,7 +116,7 @@
 	    str = strstr(p, "<a name=\"");
 	    if (str > p) {
 	       str += strlen("<a name=\"");
-	       for (i=0; str[i] && str[i] != '"'; i++)
+	       for (i=0; str[i] && str[i] != DOUBLE_QUOTES; i++)
 		  buf[i] = str[i];
 	       buf[i] = 0;
 
@@ -572,12 +573,12 @@
    /* Scan document in memory finding definition lines with upper case types */
    while (line) {
       if ((line->flags & STRUCT_FLAG)) {
-	 char *p = strchr(line->text, '"'); /* Find start of <a name="... */
+	 char *p = strchr(line->text, DOUBLE_QUOTES); /* Find start of <a name="... */
 	 assert(p);
 	 table = m_xrealloc(table, sizeof(char*) * (i + 2));
 	 table[i] = m_strdup(++p); /* Duplicate rest of line */
-	 assert(strchr(table[i], '"'));
-	 *strchr(table[i], '"') = 0; /* Eliminate ">... part after name */
+	 assert(strchr(table[i], DOUBLE_QUOTES));
+	 *strchr(table[i], DOUBLE_QUOTES) = 0; /* Eliminate ">... part after name */
 	 table[++i] = 0;
       }
       line = line->next;


Mail converted by MHonArc 2.6.19+ http://listengine.tuxfamily.org/